==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/webkit/WKBackForwardList.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.webkit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.security.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 8.0 and later.
 */
/*</javadoc>*/
/*<annotations>*/@Library("WebKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/WKBackForwardList/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class WKBackForwardListPtr extends Ptr<WKBackForwardList, WKBackForwardListPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(WKBackForwardList.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public WKBackForwardList() {}
    protected WKBackForwardList(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "currentItem")
    public native WKBackForwardListItem getCurrentItem();
    @Property(selector = "backItem")
    public native WKBackForwardListItem getBackItem();
    @Property(selector = "forwardItem")
    public native WKBackForwardListItem getForwardItem();
    @Property(selector = "backList")
    public native NSArray<WKBackForwardListItem> getBackList();
    @Property(selector = "forwardList")
    public native NSArray<WKBackForwardListItem> getForwardList();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "itemAtIndex:")
    public native WKBackForwardListItem getItem(@MachineSizedSInt long index);
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/webkit/WKBackForwardList.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.webkit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.security.*;
import org.robovm.apple.coreanimation.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*/@Library("WebKit") @NativeClass/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/WKBackForwardList/*</name>*/ 
    extends /*<extends>*/NSObject/*</extends>*/ 
    /*<implements>*//*</implements>*/ {

    /*<ptr>*/public static class WKBackForwardListPtr extends Ptr<WKBackForwardList, WKBackForwardListPtr> {}/*</ptr>*/
    /*<bind>*/static { ObjCRuntime.bind(WKBackForwardList.class); }/*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*/
    public WKBackForwardList() {}
    protected WKBackForwardList(Handle h, long handle) { super(h, handle); }
    protected WKBackForwardList(SkipInit skipInit) { super(skipInit); }
    /*</constructors>*/
    /*<properties>*/
    @Property(selector = "currentItem")
    public native WKBackForwardListItem getCurrentItem();
    @Property(selector = "backItem")
    public native WKBackForwardListItem getBackItem();
    @Property(selector = "forwardItem")
    public native WKBackForwardListItem getForwardItem();
    @Property(selector = "backList")
    public native NSArray<WKBackForwardListItem> getBackList();
    @Property(selector = "forwardList")
    public native NSArray<WKBackForwardListItem> getForwardList();
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @Method(selector = "itemAtIndex:")
    public native WKBackForwardListItem getItem(@MachineSizedSInt long index);
    /*</methods>*/
}
